pub trait Ber {
// Required methods
fn run(self: Box<Self>) -> Result<Vec<Statistics>, Box<dyn Error>>;
fn n(&self) -> usize;
fn n_cw(&self) -> usize;
fn k(&self) -> usize;
fn rate(&self) -> f64;
}Expand description
BER test.
This trait is used to define trait objects that implement BER tests.
Required Methods
Sourcefn run(self: Box<Self>) -> Result<Vec<Statistics>, Box<dyn Error>>
fn run(self: Box<Self>) -> Result<Vec<Statistics>, Box<dyn Error>>
Runs the BER test.
This function runs the BER test until completion. It returns a list of statistics for each Eb/N0, or an error.
Sourcefn n(&self) -> usize
fn n(&self) -> usize
Returns the frame size of the code.
This corresponds to the frame size after puncturing.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".